import os
import sys
from pdf2docx import Converter
import docx
import pandas as pd

# Change this to your working directory
WORK_DIR = "/home/arslantste/public_html/pdf_to_excel"

def convert_pdf_to_docx(pdf_path, docx_path):
    cv = Converter(pdf_path)
    cv.convert(docx_path, start=0, end=None)
    cv.close()

def extract_tables_or_text(docx_path, output_excel):
    doc = docx.Document(docx_path)
    tables = doc.tables

    if tables:
        with pd.ExcelWriter(output_excel) as writer:
            for i, table in enumerate(tables):
                data = []
                for row in table.rows:
                    cells = []
                    for cell in row.cells:
                        paragraphs = [p.text.strip() for p in cell.paragraphs if p.text.strip()]
                        cells.append(" ".join(paragraphs) if paragraphs else "")
                    data.append(cells)
                df = pd.DataFrame(data)
                df.to_excel(writer, sheet_name=f"Table{i+1}", index=False)
        return "success"
    else:
        # No tables found → extract all text
        text = []
        for para in doc.paragraphs:
            line = para.text.strip()
            if line:
                text.append([line])
        if text:
            df = pd.DataFrame(text, columns=["Text"])
            df.to_excel(output_excel, index=False)
            return "no-tables-text-extracted"
        else:
            return "fail"

def full_convert(pdf_path, output_excel):
    if not os.path.exists(pdf_path):
        print("pdf-not-found")
        return

    docx_temp = os.path.join(WORK_DIR, "temp.docx")
    convert_pdf_to_docx(pdf_path, docx_temp)

    result = extract_tables_or_text(docx_temp, output_excel)

    if os.path.exists(docx_temp):
        os.remove(docx_temp)

    print(result)

if __name__ == "__main__":
    if len(sys.argv) < 3:
        print("Usage: python pdf_to_excel_final.py input.pdf output.xlsx")
    else:
        full_convert(sys.argv[1], sys.argv[2])
